@@ -261,7 +261,31 @@ class AlbToFargate(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. Default: - none
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AlbToFargate.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                public_api: builtins.bool,
+                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+                container_definition_props: typing.Any = None,
+                ecr_image_version: typing.Optional[builtins.str] = None,
+                ecr_repository_arn: typing.Optional[builtins.str] = None,
+                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
+                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
+                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                fargate_service_props: typing.Any = None,
+                fargate_task_definition_props: typing.Any = None,
+                listener_props: typing.Any = None,
+                load_balancer_props: typing.Any = None,
+                log_alb_access_logs: typing.Optional[builtins.bool] = None,
+                rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+                target_group_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AlbToFargateProps(
@@ -393,7 +417,29 @@ class AlbToFargateProps:
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
-            type_hints = typing.get_type_hints(AlbToFargateProps.__init__)
+            def stub(
+                *,
+                public_api: builtins.bool,
+                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+                container_definition_props: typing.Any = None,
+                ecr_image_version: typing.Optional[builtins.str] = None,
+                ecr_repository_arn: typing.Optional[builtins.str] = None,
+                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
+                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
+                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
+                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                fargate_service_props: typing.Any = None,
+                fargate_task_definition_props: typing.Any = None,
+                listener_props: typing.Any = None,
+                load_balancer_props: typing.Any = None,
+                log_alb_access_logs: typing.Optional[builtins.bool] = None,
+                rule_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.AddRuleProps, typing.Dict[str, typing.Any]]] = None,
+                target_group_props: typing.Optional[typing.Union[aws_cdk.aws_elasticloadbalancingv2.ApplicationTargetGroupProps, typing.Dict[str, typing.Any]]] = None,
+                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
             check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
